@@ -1,10 +1,9 @@
-# -*- coding: utf-8 -*-
+# coding=utf-8
 import collections
 import csv
 import numpy as np
 import tensorflow as tf
-from tensorflow.python.data.ops.dataset_ops import ConcatenateDataset
-
+from py_common_util.common.annotations import print_exec_time
 from tensorflow_datasets.core import api_utils
 import tensorflow_datasets as tfds
 from tensorflow.python import feature_column
@@ -58,7 +57,7 @@ class DefaultDatasetBuilderConfig(tfds.core.BuilderConfig):
 
 class SuperDatasetBuilder(tfds.core.GeneratorBasedBuilder):
     """
-    tensorflow dataset builder
+    tensorflow dataset builder https://www.tensorflow.org/datasets/catalog/overview
     """
     BUILDER_CONFIGS = [
         DefaultDatasetBuilderConfig(
@@ -215,14 +214,14 @@ class SuperDatasetBuilder(tfds.core.GeneratorBasedBuilder):
         return SuperDatasetBuilder.convert_to_int_from_string(string, dtype, count, sep)
 
     @staticmethod
-    @CommonUtils.print_exec_time
+    @print_exec_time
     def build_and_download_and_prepare(dataset_builder_cls_name=None, config_name="plain_text"):
         dataset_builder = tfds.builder(dataset_builder_cls_name + "/" + config_name)
         dataset_builder.download_and_prepare()
         return dataset_builder.info
 
     @staticmethod
-    @CommonUtils.print_exec_time
+    @print_exec_time
     def load_batched_datasets(dataset_builder_cls_name=None,
                              config_name=None,
                              split=[tfds.Split.ALL],
@@ -305,9 +304,17 @@ class SuperDatasetBuilder(tfds.core.GeneratorBasedBuilder):
     @staticmethod
     def split_full_datasets(full_datasets: tf.data.Dataset, num_examples=0, train_size=0.7, validation_size=0, test_size=0.3):
         """
-        num_examples=total num examples | total num batched
+        按比例切割数据集
+        或依赖sklearn工具: from sklearn.model_selection import train_test_split
+        # 采用 80 - 20 的比例切分训练集和验证集
+        # input_tensor_train, input_tensor_val, target_tensor_train, target_tensor_val = train_test_split(input_tensor, target_tensor, test_size=0.2)
+        :param full_datasets 开发调试时可以取部分数据，e.g. 让full_datasets=full_datasets.take(10)
+        :param num_examples, e.g. total num examples | total num batched
+        :param train_size e.g. 0.7 或 0.1
+        :param validation_size e.g. 0.1 或 0
+        :param test_size e.g. 0.2 或 0
         ```
-            train_dataset, validation_dataset, test_dataset = MovieLensDatasetBuilder.split_full_datasets(full_datasets,
+            train_data, validation_data, test_data = MovieLensDatasetBuilder.split_full_datasets(full_datasets,
                                                                                                   num_examples=MovieLensDatasetBuilder.get_total_num_batch(
                                                                                                       num_examples,
                                                                                                       128),
@@ -334,6 +341,7 @@ class SuperDatasetBuilder(tfds.core.GeneratorBasedBuilder):
         # validation_dataset = test_dataset.skip(validation_size)
         # test_dataset = test_dataset.take(test_size)
         # 用shard方法获取数据集比较快，注意要确保shard之后再去做shuffle的操作
+
         train_dataset = full_datasets.take(0)
         validation_dataset = full_datasets.take(0)
         test_dataset = full_datasets.take(0)
@@ -488,6 +496,7 @@ class SuperDatasetBuilder(tfds.core.GeneratorBasedBuilder):
     @staticmethod
     def build_one_hot_feature_column(categorical_column):
         """
+        支持one_hot和multi-hot两种模式：i.e. If my input is ["bob", "wanda"] or [0, 2], I want to get a [1, 0, 1] vector and not [[1, 0, 0], [0, 0, 1]]
         for tf.estimator https://www.tensorflow.org/guide/feature_columns?hl=zh-cn
         查看feature_columns的值：tf.keras.layers.DenseFeatures(feature_columns)(example).numpy()
         or tf.feature_column.input_layer(features, [feature_column]).numpy()
@@ -787,4 +796,13 @@ DEMO_FEATURE_DICT = collections.OrderedDict([
     ("boat", (tf.string, SuperDatasetBuilder.convert_to_string)),
     ("body", (tf.int32, SuperDatasetBuilder.convert_to_int)),
     ("home.dest", (tf.string, SuperDatasetBuilder.convert_to_string))
-])
\ No newline at end of file
+])
+
+if __name__ == '__main__':
+    batched_datasets = SuperDatasetBuilder.load_batched_datasets("ted_hrlr_translate",
+                                                                 config_name="ru_to_en",
+                                                                 split=[tfds.Split.TRAIN])
+    batched_dataset_features = SuperDatasetBuilder.read_batched_datasets(batched_datasets)
+    for features, labels in batched_dataset_features:
+        print(f"features={''.join([feature.decode('utf-8') for feature in features])}, labels={''.join([label.decode('utf-8') for label in labels])}")
+    print(f"end!!")
