@@ -6,11 +6,11 @@ import logging
 import numpy as np
 import threading
 import time
-
 import ray
 from ray.experimental import internal_kv
+from pyarrow import plasma
 # from ray.experimental.async_api import thread_safe_client
-from skydl.ray.experimental.async_api_patch0_8_1 import thread_safe_client
+from skydl.ray.experimental.async_api_0_8_4 import as_future as thread_safe_client
 # from skydl.ray.worker_patch0_7_5 import global_worker as ray075_global_worker
 
 logger = logging.getLogger(__name__)
@@ -44,11 +44,19 @@ def experimental_plasma_get(object_id):
     (ref issue: https://github.com/ray-proje ct/ray/issues/5624)
     fixed issue from ray>=0.7.5(v0.7.4 is ok): ray.exceptions.UnreconstructableError: Object beb3495e54ebcd4975589c820000000000000000 is lost (either LRU evicted or deleted by user) and cannot be reconstructed. Try increasing the object store memory available with ray.init(object_store_memory=<bytes>) or setting object store limits with ray.remote(object_store_memory=<bytes>)
     """
-    plasma_id = ray.pyarrow.plasma.ObjectID(object_id)
-    plasma_client = thread_safe_client(
-        ray.pyarrow.plasma.connect(ray.worker.global_worker.node.plasma_store_socket_name, None, 0, 300))
+    # plasma_id = ray.pyarrow.plasma.ObjectID(object_id)
+    # plasma_client = thread_safe_client(
+    #     ray.pyarrow.plasma.connect(ray.worker.global_worker.node.plasma_store_socket_name, None, 0, 300))
+    # while not plasma_client.contains(plasma_id):
+    #     pass
+    # return plasma_client.get(plasma_id)
+    plasma_id = plasma.ObjectID(object_id)
+    plasma_client = plasma.connect(ray.worker.global_worker.node.plasma_store_socket_name, 10)
+    thread_safe_client(ray.ObjectID(object_id))
     while not plasma_client.contains(plasma_id):
+        print(f"plasma_client.contains(plasma_id): {plasma_client.contains(plasma_id)}")
         pass
+    print(f"plasma_client.contains(plasma_id), plasma_id={plasma_id}")
     return plasma_client.get(plasma_id)
 
 
